@@ -8,6 +8,7 @@ dictionary to store any additional information about the population as a whole.
 __author__ = "Brian Connelly <bdc@msu.edu>"
 __credits__ = "Brian Connelly"
 
+import itertools
 import random
 
 from seeds.Experiment import *
@@ -31,6 +32,9 @@ class Population(object):
     config_section
         A string containing the section under which this population is
         configured
+    cell_id_manager
+        Keeps track of Cell IDs and provides unique IDs using the get_cell_id
+        method.
     _cell_class
         A reference to the proper class for the configured Cell type
 
@@ -48,6 +52,8 @@ class Population(object):
         if not self.experiment.config.has_section(self.config_section):
             raise ConfigurationError("Configuration section %s not defined" % (self.config_section))
 
+        self.cell_id_manager = itertools.count(0)
+
         self.experiment.data['population']['type_count'] = []
         self.experiment.data['population']['transitions'] = []
 
@@ -89,7 +95,7 @@ class Population(object):
         # coordinates of the node
         for n in self.topology.graph.nodes():
             c = self._cell_class(experiment=self.experiment, population=self,
-                                 id=n, label=label)
+                                 node=n, label=label)
             self.topology.graph.node[n]['cell'] = c
 
         # Now that all Cells are present, set their neighbors list.  This can
@@ -117,10 +123,10 @@ class Population(object):
         self.experiment.data['population']['transitions'] = [[0]*num_types for i in range(num_types)]
 
         # Select a set of cells to update and update them
-        events = self.experiment.config.getint(section=self.experiment.config_section,
+        events = self.experiment.config.getint(section=self.config_section,
                                                name='events_per_epoch',
                                                default=len(self.topology.graph))
-        nodes_to_update = sample_with_replacement(self.topology.graph.nodes(), n=events)
+        nodes_to_update = sample_with_replacement(self.topology.graph.nodes(), k=events)
         [self.topology.graph.node[n]['cell'].update() for n in nodes_to_update]
 
     def teardown(self):
@@ -198,7 +204,7 @@ class Population(object):
 
         return self.topology.node_distance(src.id, dest.id)
 
-    def add_cell(self, cell=None, neighbors=[]):
+    def add_cell(self, cell=None, neighbors=[], coords=None):
         """Add a Cell of the appropriate type to the population and connect it
         to the given neighbors (optional).
 
@@ -208,6 +214,10 @@ class Population(object):
             An initialized Cell object to be added
         *neighbors*
             List of Cells to be connected to the newly-created Cell
+        *coords*
+            A tuple containing the coordinates of the new cell.  The degree of
+            this tuple must match the number of dimensions represented in the
+            topology.  If none are supplied, the origin (0,..,0) will be used.
 
         """
 
@@ -217,13 +227,16 @@ class Population(object):
         new_id = max(self.topology.graph.nodes()) + 1
 
         try:
-            self.topology.add_node(id=new_id, neighbors=neighbor_ids)
+            self.topology.add_node(id=new_id, neighbors=neighbor_ids, coords=coords)
         except NonExistentNodeError as err:
-            print("Error adding Cell: %s" % (err))
+            # Perhaps a different exception would make more sense
+            raise NonExistentNodeError(new_id)
 
         if not Cell:
             cell = self._cell_class(experiment=self.experiment,
                                     population=self, id=new_id)
+        else:
+            cell.id = new_id
 
         self.topology.graph.node[n]['cell'] = cell
 
@@ -288,3 +301,10 @@ class Population(object):
         except NonExistentEdgeError as err:
             print("Error disconnecting Cells: %s" % (err))
 
+    def get_cell_id(self):
+        """Return a unique ID to be used for a Cell"""
+        return self.cell_id_manager.next()
+
+    def get_neighbors(self, cell):
+        """Return a list of the neighbors for the given cell"""
+        return [self.topology.graph.node[n]['cell'] for n in self.topology.get_neighbors(cell.node)]
