@@ -44,13 +44,20 @@ class VonNeumannTopology(Topology):
         radius = 4
 
     """
-    def __init__(self, experiment, config_section='VonNeumannTopology'):
+
+    def __init__(self, experiment, label=None):
         """Initialize a VonNeumannTopology object"""
-        super(VonNeumannTopology, self).__init__(experiment, config_section=config_section)
+        super(VonNeumannTopology, self).__init__(experiment, label=label)
+
+        if self.label:
+            self.config_section = "%s:%s" % ("VonNeumannTopology", self.label)
+        else:
+            self.config_section = "%s" % ("VonNeumannTopology")
 
         self.size = self.experiment.config.getint(self.config_section, 'size')
         self.periodic = self.experiment.config.getboolean(self.config_section, 'periodic', default=False)
         self.radius = self.experiment.config.getint(self.config_section, 'radius', default=1)
+        self.dimensions = 2
 
         if not self.size:
             raise ConfigurationError("VonNeumannTopology: size parameter must be defined")
