@@ -11,7 +11,7 @@ import itertools
 import random
 
 
-def roulette_select(items=[], fitnesses=[], n=1):
+def roulette_select(items=[], fitnesses=[], k=1):
     """Perform a fitness-proportional selection using a roulette wheel
 
     Parameters:
@@ -21,7 +21,10 @@ def roulette_select(items=[], fitnesses=[], n=1):
     *fitnesses*
         A list of fitnesses of the corresponding items.  Larger values
         represent larger fitnesses and larger probabilities of being selected.
-    *n*
+        Additionally, non-negative values are assumed.  Data that do not
+        conform to these rules should be transformed before being passed to
+        this function.
+    *k*
         Number of items to select (default: 1)
 
     """
@@ -36,7 +39,7 @@ def roulette_select(items=[], fitnesses=[], n=1):
     p = [sum(rel_fitnesses[:i+1]) for i in range(len(rel_fitnesses))]
 
     winners = []
-    while len(winners) < n:
+    while len(winners) < k:
         for i in range(len(items)):
             if random.random() < p[i]:
                 winners.append(items[i])
@@ -44,14 +47,14 @@ def roulette_select(items=[], fitnesses=[], n=1):
 
     return winners
 
-def sample_with_replacement(items=[], n=1):
+def sample_with_replacement(items=[], k=1):
     """Get a list of samples from a given set of items with replacement.
 
     Parameters:
 
     *items*
         A list of items from which to select
-    *n*
+    *k*
         Number of items to select (default: 1)
 
     """
@@ -62,8 +65,24 @@ def sample_with_replacement(items=[], n=1):
     if popsize < 1:
         print("Error: Must supply items")
 
-    if n < 1:
+    if k < 1:
         print("Error: Invalid number of samples")
 
     _random, _int = random.random, int
-    return [items[_int(_random() * popsize)] for i in itertools.repeat(None, n)]
+    return [items[_int(_random() * popsize)] for i in itertools.repeat(None, k)]
+
+def sample_without_replacement(items=[], k=1):
+    """Get a list of samples from a given set of items without replacement.
+
+    This function is merely a wrapper for Python's random.sample()
+
+    Parameters:
+
+    *items*
+        A list of items from which to select
+    *k*
+        Number of items to select (default: 1)
+
+    """
+
+    return random.sample(items, k)
